<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Apr 21, 2020
 */

/**
 * Acronis Backup Plan api.
 *
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Model_BackupPlan_Api extends Model_Api
{
    private $_cookieClient;

    /**
     * Constructor.
     */
    public function __construct()
    {
        $this->_cookieClient = $this->_getCookieClient();
    }

    /**
     * Get backup plan by id.
     *
     * @param string $id
     * @return array
     */
    public function getPlanById($id)
    {
        $apiEndpoint = "/bc/api/ams/backup/plans/$id";
        $plan = $this->_cookieClient->sendAuthenticatedGetRequest($apiEndpoint);

        if (empty($plan)) {
            throw new Exception('Backup plan does not exist! ' . $id);
        }

        return $plan;
    }

    /**
     * Add resource to plan.
     *
     * @param string $planId
     * @param string $instanceId
     */
    public function addResourceToPlan($planId, $instanceId)
    {
        $apiEndpoint = '/bc/api/ams/backup/plan_operations/add_resources';
        $config = $this->_getPlanDataConfig($planId, $instanceId);

        $res = $this->_cookieClient->sendAuthenticatedPostRequest($apiEndpoint, $config);
        return $res;
    }

    /**
     * Remove resource from backup plan.
     *
     * @param string $planId
     * @param string $instanceId
     * @return array
     */
    public function removeResourceFromPlan($planId, $instanceId)
    {
        $apiEndpoint = '/bc/api/ams/backup/plan_operations/remove_resources';
        $config = $this->_getPlanDataConfig($planId, $instanceId);

        $res = $this->_cookieClient->sendAuthenticatedPostRequest($apiEndpoint, $config);
        return $res;
    }

    /**
     * Run backup.
     *
     * @param string $planId
     * @param string $instanceId
     * @return array
     */
    public function runBackup($planId, $instanceId)
    {
        $apiEndpoint = '/bc/api/ams/backup/plan_operations/run';
        $config = $this->_getPlanDataConfig($planId, $instanceId);

        $res = $this->_cookieClient->sendAuthenticatedPostRequest($apiEndpoint, $config);
        return $res;
    }

    /**
     * Get plan data configuration.
     *
     * @param string $planId
     * @param string $instanceId
     * @return array
     */
    private function _getPlanDataConfig($planId, $instanceId)
    {
        $data = array(
            'resourcesIds' => array($instanceId),
            'planId' => $planId
        );

        return array(
            'data' => $data
        );
    }
}
