<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Apr 21, 2020
 */

/**
 *
 *
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Model_CloudStorage_Api extends Model_Api
{
    private $_cookieClient;

    /**
     * Constructor.
     * Sends api request to determine resource id & device specific data.
     */
    public function __construct()
    {
        $this->_cookieClient = $this->_getCookieClient();
    }

    /**
     * Get device info.
     *
     * @return array
     */
    public function getDevice()
    {
        $allDevices = $this->_cookieClient->sendAuthenticatedGetRequest('/bc/api/ams/resources');
        $device = $this->_getDeviceByServerName($allDevices);
        return $device;
    }


    /**
     * Get device information from response.
     *
     * @param array $allDevices
     * @return array
     */
    private function _getDeviceByServerName(array $allDevices)
    {
        foreach ($allDevices as $device) {
            if ($this->_deviceDataIncludesServerName($device)) {
                return $device;
            }
        }
    }

    /**
     * Check if item is server.
     *
     * @param array $device
     * @return boolean
     */
    private function _deviceDataIncludesServerName(array $device)
    {
        return $device['server'] && gethostname() === $device['title'];
    }

    /**
     * Get device storage size.
     *
     * @param string $instanceId
     * @return string
     */
    public function getStorageData($instanceId)
    {
        $apiEndpoint = "/bc/api/vault_manager/v1/stats?resourceId=$instanceId&storageType=online";
        $storageInfo = $this->_cookieClient->sendAuthenticatedGetRequest($apiEndpoint);
        return $storageInfo;
    }
}
