<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Apr 20, 2020
 */

/**
 * CloudStorage class.
 *
 * @package InterWorx
 * @subpackage Plugin_Acronis
 */
class Model_CloudStorage_CloudStorage extends Model_Acronis
{
    private $_resourceId;
    private $_instanceId;

    private $_lastBackup;
    private $_nextBackup;
    private $_online;
    private $_status;

    /**
     * Get instanceId from cache or
     */
    public function getInstanceId()
    {
        $instanceId = $this->_getCache()->getInstanceId();

        if (!isset($instanceId)) {
            $this->_setCloudStorage();
            $instanceId = $this->_instanceId;
            $this->_getCache()->cacheInstanceId($instanceId);
        }

        return $instanceId;
    }

    /**
     * Get resource if from cache or api.
     *
     * @return string
     */
    public function getResourceId()
    {
        $resourceId = $this->_getCache()->getResourceId();

        if (!isset($resourceId)) {
            $this->_setCloudStorage();
            $resourceId = $this->_resourceId;
            $this->_getCache()->cacheResourceId($resourceId);
        }

        return $resourceId;
    }

    /**
     * Get last date string.
     *
     * @return string
     */
    public function getLastBackup()
    {
        if (!isset($this->_lastBackup)) {
            $this->_setCloudStorage();
        }

        return $this->_formatDate($this->_lastBackup);
    }

    /**
     * Get next backup date string.
     *
     * @return string
     */
    public function getNextBackup()
    {
        if (!isset($this->_nextBackup)) {
            $this->_setCloudStorage();
        }

        return $this->_formatDate($this->_nextBackup);
    }


    /**
     * Check if machine is online.
     *
     * @return boolean
     */
    public function isOnline()
    {
        if (!isset($this->_online)) {
            $this->_setCloudStorage();
        }

        return $this->_online;
    }

    /**
     * Get last backup status.
     *
     * @return string
     */
    public function isProtected()
    {
        if (!isset($this->_status)) {
            $this->_setCloudStorage();
        }

        return $this->_status !== 'not_protected';
    }

    /**
     * Get status.
     *
     * @return string
     */
    public function getStatus()
    {
        if (!isset($this->_status)) {
            $this->_setCloudStorage();
        }
        return $this->_status;
    }


    /**
     * Set device info.
     */
    private function _setCloudStorage()
    {
        $device = $this->_getCache()->getDeviceInfo();

        if (empty($device)) {
            $Api = $this->_getApi();
            $apiResponse = $Api->getDevice();
            $device = $this->_formatDeviceInfoFromApi($apiResponse);
            $this->_getCache()->cacheDeviceInfo($device);
        }

        $this->_resourceId = $device['resourceId'];
        $this->_lastBackup = $device['lastBackup'];
        $this->_nextBackup = $device['nextBackup'];
        $this->_online = $device['online'];
        $this->_instanceId = $device['instanceId'];
        $this->_status = $device['status'];
    }

    /**
     *
     * Format device info from api.
     *
     * @param array $deviceInfo
     * @return array
     */
    private function _formatDeviceInfoFromApi(array $deviceInfo)
    {
        return array(
            'resourceId' => $deviceInfo['id'],
            'lastBackup' => $deviceInfo['lastBackup'],
            'nextBackup' => $deviceInfo['nextBackup'],
            'online' => $deviceInfo['online'],
            'instanceId' => $deviceInfo['instanceId'],
            'status' => $deviceInfo['status']
        );
    }

    /**
     * Get device storage size.
     *
     * @return string
     */
    public function getStorageData()
    {
        if (!isset($this->_instanceId)) {
            $this->_setCloudStorage();
        }

        $Api = $this->_getApi();
        $storageInfo = $Api->getStorageData($this->_instanceId);
        $gb = $this->_convertBytes($storageInfo['occupied_data_size']);
        return array('size' => $gb);
    }
}
