<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    May 11, 2020
 */

/**
 *
 *
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Model_RecoveryPlan_RecoveryPlan extends Model_Acronis
{

    const RECOVERY_DIR_NAME = 'acronis_temp';
    const NW_DOWNLOAD_DIR_PATH = '/home/' . self::RECOVERY_DIR_NAME;

    private $_machineId;
    private $_legacyId;
    private $_subscriptionId;
    private $_agentTenantId;
    private $_backupId;
    private $_created;

    /**
     * Constructor.
     *
     * @param Model_RecoveryPoint_RecoveryPoint $RecoveryPoint
     */
    public function __construct(Model_RecoveryPoint_RecoveryPoint $RecoveryPoint)
    {

        $this->_machineId = $RecoveryPoint->getMachineId();
        $this->_legacyId = $RecoveryPoint->getLegacyId();
        $this->_subscriptionId = $RecoveryPoint->getSubscriptionId();
        $this->_created = $RecoveryPoint->getCreated();
        $this->_agentTenantId = $RecoveryPoint->getAgentTenantId();
        $this->_backupId = $RecoveryPoint->getBackupId();
    }

    /**
     * @param array   $dirIds
     * @param boolean $deleteNewerFiles
     */
    public function recoverDirectories(array $dirIds, $deleteNewerFiles = false)
    {
        $Api =  $this->_getRecoveryApi();

        if ($deleteNewerFiles) {
            $this->_deleteNewerFiles($dirIds);
        }

        $Api->recoverDirectories($this->_agentTenantId, $dirIds);
    }

    /**
     * Delete newer files if directory.
     *
     * @param array $dirIds
     */
    protected function _deleteNewerFiles(array $dirIds)
    {
        $this->_getRecoveryApi()->deleteFilesCreatedAfter($this->_created);

        foreach ($dirIds as $dirId) {
            $this->_deleteNewContentIfDir($dirId);
        }
    }

    /**
     * Delete new content if directory.
     *
     * @param string $id
     */
    private function _deleteNewContentIfDir($id)
    {
        $dir = $this->_getCache()->getFileDetails($this->_backupId, $id);
        if ($dir['type'] === 'dir') {
            $path = $dir['displayPath'];
            $this->_getRecoveryApi()->addPathDeleteAfter($path);
        }
    }

    /**
     * @param array $dirIds
     */
    public function restoreToAltLocation(array $dirIds)
    {
        $newDirName = strtotime('now');
        $path = self::NW_DOWNLOAD_DIR_PATH . "/$newDirName/";

        $this->_createRestoreAltLocationDir($path);
        $this->_getRecoveryApi()->recoverDirectoriesToAltLocation($this->_agentTenantId, $dirIds, $path);
    }

    /**
     * @param array $dirIds
     */
    public function restoreToSwAltLocation(array $dirIds)
    {
        $newDirName = strtotime('now');
        $path = self::getSwRestoreAltLocationPath() . "/$newDirName/";

        $this->_createRestoreAltLocationDir($path);
        $this->_getRecoveryApi()->recoverDirectoriesToAltLocation($this->_agentTenantId, $dirIds, $path);
    }

    /**
     * Get sw alt location path.
     *
     * @return string
     */
    public static function getSwRestoreAltLocationPath()
    {
        $root = IW::SW()->getPackageRoot();
        $recoveryDir = self::RECOVERY_DIR_NAME;
        return "$root/$recoveryDir";
    }

    /**
     * Get sw alt location path.
     *
     * @return string
     */
    public static function getNwRestoreAltLocationPath()
    {
        return self::NW_DOWNLOAD_DIR_PATH;
    }


    /**
     * Create dirs for restoring to alt location & downloading content.
     *
     * @param string $path
     */
    protected function _createRestoreAltLocationDir($path)
    {
        $mkdirCommand = "mkdir -p $path && chmod 0755 $path";
        $Command = new Command($mkdirCommand);
        $Command->runAsRoot();
        $Command->exec();
    }

    /**
     * get api with params.
     */
    private function _getRecoveryApi()
    {
        $Api = $this->_getApi([$this->_legacyId, $this->_machineId, $this->_subscriptionId]);
        return $Api;
    }
}
