<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Apr 13, 2020
 */

/**
 * Acronis backups api.
 *
 * @package Interworx
 * @subpackage Plugin
 */
class Model_RecoveryPoint_Api extends Model_Api
{
    private $_cookieClient;

    /**
     * Constructor.
     */
    public function __construct()
    {
        $this->_cookieClient = $this->_getCookieClient();
    }

    /**
     * Get subscription id.
     *
     * @return string
     */
    public function getSubscriptionId()
    {
        $endpoint = '/bc/api/subscriptions';
        $config = $this->_getSubscriptionConfig();

        $res = $this->_cookieClient->sendAuthenticatedPostRequest($endpoint, $config);
        return $res['id'];
    }

    /**
     * Get subscription request config.
     *
     * @return array
     */
    private function _getSubscriptionConfig()
    {
        $headers = array(
            'Accept' => 'application/json'
        );

        return array('headers' => $headers);
    }

    /**
     * Get directory content from acronis api.
     * Defaults to root directory.
     *
     * @param string $legacyId
     * @param string $machineId
     * @param string $directoryId
     * @return array
     */
    public function getDirectoryContent($legacyId, $machineId, $directoryId = null)
    {
        $postData = $this->_getDirectoryContentPostData($legacyId, $machineId, $directoryId);
        $apiEndpoint = $this->_getApiEndpoint($postData);
        $config = array('data' => $postData);

        return $this->_cookieClient->sendAuthenticatedPostRequest($apiEndpoint, $config);
    }

    /**
     * Get post data.
     *
     * @param string $legacyId
     * @param string $machineId
     * @param string $directoryId
     * @return array
     */
    private function _getDirectoryContentPostData($legacyId, $machineId, $directoryId = null)
    {
        return array(
            'backupId' => $legacyId,
            'id' => $directoryId,
            'limit' => 200,
            'machineId' => $machineId,
            'maxRequestTimeout' => 600000,
            'timeout' => 30,
            'top' => 0,
            'type' => 'files'
        );
    }

    /**
     * Get recovery point url.
     *
     * @param array $postData
     */
    private function _getApiEndpoint(array $postData)
    {
        $query = http_build_query($postData);
        return "/bc/api/ams/archives/%3CpatharchiveId%3E/backups/%3CpathbackupId%3E/items?$query";
    }
}
