<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Apr 21, 2020
 */

/**
 *
 *
 * @package Interworx
 * @subpackage Plugin_Acronis
 */
class Model_Resource_Api extends Model_Api
{
    private $_cookieClient;

    /**
     * Constructor.
     */
    public function __construct()
    {
        $this->_cookieClient = $this->_getCookieClient();
    }

    /**
     * Get all plans assigned to the resource.
     *
     * @param string $instanceId
     * @return array
     */
    public function getBackupPlans($instanceId)
    {
        $apiEndpoint = "/bc/api/ams/protected_resources?resourcesIds=$instanceId";
        return $this->_cookieClient->sendAuthenticatedGetRequest($apiEndpoint);
    }

    /**
     * Get resource status, includes lastBackup & nextBackup.
     *
     * @param string $instanceId
     * @return array
     */
    public function getStatus($instanceId)
    {
        $apiEndpoint = "/bc/api/ams/protected_resources?resourcesIds=$instanceId";
        $resourceInfo = $this->_cookieClient->sendAuthenticatedGetRequest($apiEndpoint);
        return $resourceInfo;
    }

    /**
     * Get applicable plans/ existing plans not assigned to the resource.
     *
     * @param string $instanceId
     * @return array
     */
    public function getApplicablePlans($instanceId)
    {
        $apiEndpoint = '/bc/api/ams/backup/plan_draft_operations/get_applicable_plans';
        $config = $this->_getPlansConfig($instanceId);

        $res = $this->_cookieClient->sendAuthenticatedPostRequest($apiEndpoint, $config);
        return $res;
    }

    /**
     * Get config for plans post.
     *
     * @param string $instanceId
     * @return array
     */
    private function _getPlansConfig($instanceId)
    {
        $data = array(
            'resourcesIds' => [$instanceId]
        );

        return array(
            'data' => $data
        );
    }

    /**
     * Get list of backups.
     *
     * @param string $resourceId
     * @return array
     */
    public function getBackups($resourceId)
    {
        $endpoint = "/bc/api/vault_manager/v1/backups?count=1&embed=archive&includeActions=1&limit=25&order=desc(created)&resourceId=$resourceId";
        $backups = $this->_cookieClient->sendAuthenticatedGetRequest($endpoint);
        return $backups;
    }
}
