<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Jun 25, 2020
 */
require_once(__DIR__ . '/../mock/OAuthMock.php');
require_once(__DIR__ . '/../mock/BackupAgent.php');
require_once(__DIR__ . '/../mock/CloudStorage.php');
require_once(__DIR__ . '/../mock/BackupPlan.php');
require_once(__DIR__ . '/../mock/Auth.php');
require_once(__DIR__ . '/../mock/Resource.php');
require_once(__DIR__ . '/../mock/RecoveryPlan.php');



class AcronisCtrlTest extends IWorx_Framework_TestCase
{
    const VIEW_ERROR_MSG = 'ab_error_message';
    const VIEW_INSTALL_AGENT = 'install_backup_agent';
    const EXPECTED_MESSAGE_NOT_AUTHORIZED = '##LG_ACRONIS_NOT_AUTHORIZED##';
    const CTRL_NW = 'Ctrl_Nodeworx_Acronis';
    const CTRL_SW = 'Ctrl_Siteworx_Acronis';


    const INDEX_ACTION = 'index';
    const INSTALL_ACTION = 'installBackupAgentCommit';
    const UNINSTALL_ACTION = 'uninstallBackupAgentCommit';
    const CLOUDSTORAGE_ACTION = 'cloudstoragecommit';
    const BACKUPPLAN_ACTION = 'backupPlanStatusCommit';
    const BACKUPINFO_ACTION = 'backupInfoCommit';
    const REDIRECT_ACTION = 'redirectToBackupCloudCommit';
    const REVOKE_PLAN_ACTION = 'revokePlanCommit';
    const ACTIVATE_PLAN_ACTION = 'activatePlanCommit';
    const RUN_BACKUP_ACTION = 'runBackupCommit';
    const LIST_BACKUPS_ACTION = 'listBackupsCommit';
    const GET_ROOT_DIR_ACTION = 'getRootContentCommit';
    const GET_DIR_ACTION = 'getDirectoryContentByIdCommit';
    const RECOVER_DIRS_ACTION = 'recoverDirectoriesCommit';
    const RESTORE_ALT_LOCATION_ACTION = 'restoreToAltLocationCommit';

    const THROW_EXCEPTION = true;
    const NO_EXCEPTION = false;
    const SHOULD_FAIL_MSG = 'Should display failure if model throws exception';
    const SHOULD_SUCCEED_MSG = 'Should return success.';


    /**
     * Make sure oauth mock is used in tests. Defaults to authorized.
     */
    public function setUp()
    {
        $isAuthorized = true;
        $this->_setMockOAuthApi($isAuthorized);
    }



    /**
     * Set moch auth api.
     *
     * @param boolean $isAuthorized
     */
    protected function _setMockOAuthApi($isAuthorized)
    {
        $ApiClient = new OAuthMock($isAuthorized);
        $Plugin = $this->_getPlugin();
        $Plugin->setOAuthApiClient($ApiClient);
    }


    /**
     * Get plugin class.
     *
     * @return Plugin
     */
    private function _getPlugin()
    {
        return IW::PluginManager()->getPlugin('acronis');
    }


    /**
     * send request to ctrl.
     *
     * @param string $action
     * @param array  $input
     * @return Reply
     */
    protected function _sendNwCtrlRequest($action, array $input = array())
    {
        $NW = self::getMasterNodeWorx();
        $Reply = IW::FC()->routeFromPHP(
            self::CTRL_NW,
            $action,
            $input,
            $NW
        );

        return $Reply;
    }

    /**
     * send request to ctrl.
     *
     * @param string $action
     * @param array  $input
     * @return Reply
     */
    protected function _sendSwCtrlRequest($action, array $input = array())
    {
        $SW = $this->getSWAccount();
        $Reply = IW::FC()->routeFromPHP(
            self::CTRL_SW,
            $action,
            $input,
            $SW
        );

        return $Reply;
    }

    /**
     * set mock recovey plan.
     *
     * @param boolean $throwException
     */
    protected function _setMockRecoveryPlan($throwException)
    {
        $Mock = new Mock_RecoveryPlan($throwException);
        $this->_getPlugin()->setRecoveryPlan($Mock);
    }

    /**
     * Set mock resource.
     *
     * @param boolean $throwException
     */
    protected function _setMockResource($throwException)
    {
        $Mock = new Mock_Resource($throwException);
        $this->_getPlugin()->setResource($Mock);
    }

    /**
     * Set auth mock.
     *
     * @param boolean $throwException
     */
    protected function _setAuthMock($throwException)
    {
        $Mock = new Mock_Auth($throwException);
        $this->_getPlugin()->setAuth($Mock);
    }

    /**
     * Set mock cloud storage.
     *
     * @param boolean $throwException
     */
    protected function _setMockCloudStorage($throwException)
    {
        $MockCloudStorage = new Mock_CloudStorage($throwException);
        $this->_getPlugin()->setCloudStorage($MockCloudStorage);
    }

    /**
     * Set mock backup plan.
     *
     * @param boolean $throwException
     */
    protected function _setMockBackupPlan($throwException)
    {
        $MockBackupPlan = new Mock_BackupPlan($throwException);
        $this->_getPlugin()->setBackupPlan($MockBackupPlan);
    }

    /**
     * set mock installer.
     *
     * @param boolean $isInstalled
     */
    protected function _setMockBackupAgent($isInstalled)
    {
        $MockBackupAgent = new Mock_BackupAgent($isInstalled);
        $Plugin = $this->_getPlugin();
        $Plugin->setBackupAgent($MockBackupAgent);
    }
}
