<?php

/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Feb 17, 2020
 */

 require_once(__DIR__ . '/AcronisCtrlTest.php');


class Ctrl_Nodeworx_AcronisTest extends AcronisCtrlTest
{
    /**
     * index action - should display error message when user not authorized.
     */
    public function testIndexActionShouldFailIfCredentialsInvalid()
    {
        $isAuthorized = false;
        $this->_setMockOAuthApi($isAuthorized);

        $Reply = $this->_sendNwCtrlRequest(self::INDEX_ACTION);
        $this->assertReplyNotSuccessful($Reply, 'Expected index action to return Fail');

        $replyData = $Reply->getData();
        $this->assertContains(self::EXPECTED_MESSAGE_NOT_AUTHORIZED, $replyData);
    }

    /**
     * index action - should not display any error messages if user is authorized.
     */
    public function testIndexActionShouldReturnSuccessfulReplyIfCredentialsValid()
    {
        $Reply = $this->_sendNwCtrlRequest(self::INDEX_ACTION);
        $this->assertReplySuccessful($Reply, 'Expected successful reply from index action when user is authorized.');
    }

    /**
     * Test install backup agent - should succeed if not installed.
     */
    public function testInstallBackupAgentCommitActionShouldDisplaySuccess()
    {
        $isInstalled = false;
        $this->_setMockBackupAgent($isInstalled);

        $Reply = $this->_sendNwCtrlRequest(self::INSTALL_ACTION);
        $this->assertReplySuccessful($Reply);
    }

    /**
     * Test uninstall backup agent - when not installed.
     */
    public function testUninstallBackupAgentCommitActionShouldFailIfNotInstalled()
    {
        $isInstalled = false;
        $this->_setMockBackupAgent($isInstalled);

        $Reply = $this->_sendNwCtrlRequest(self::UNINSTALL_ACTION);
        $this->assertReplyNotSuccessful($Reply, 'Expected unsuccessful reply when backup agent isn\'t installed.');
    }


    /**
     * Test uninstall backup agent - when installed.
     */
    public function testUninstallBackupAgentCommitActionShouldDisplaySuccessIfInstalled()
    {
        $isInstalled = true;
        $this->_setMockBackupAgent($isInstalled);

        $Reply = $this->_sendNwCtrlRequest(self::UNINSTALL_ACTION);
        $this->assertReplySuccessful($Reply, 'Expected successful reply when backup agent is installed.');
    }

    /**
     * Test cloud storage action - should catch exception and display failure.
     */
    public function testCloudstorageCommitActionShouldFailIfModelThrowsException()
    {
        $this->_setMockCloudStorage(self::THROW_EXCEPTION);

        $Reply = $this->_sendNwCtrlRequest(self::CLOUDSTORAGE_ACTION);
        $this->assertReplyNotSuccessful($Reply, self::SHOULD_FAIL_MSG);
    }

    /**
     * Test cloud storage action - should return successful reply.
     */
    public function testCloudstorageCommitActionShouldDisplaySuccess()
    {
        $this->_setMockCloudStorage(self::NO_EXCEPTION);

        $Reply = $this->_sendNwCtrlRequest(self::CLOUDSTORAGE_ACTION);
        $this->assertReplySuccessful($Reply, self::SHOULD_SUCCEED_MSG);
    }

    /**
     * Test BackupPlanStatusCommit action. Should return unsuccessful reply if model throws exception.
     */
    public function testBackupPlanStatusCommitActionShouldFail()
    {
        $this->_setMockBackupPlan(self::THROW_EXCEPTION);
        $this->_setMockCloudStorage(self::THROW_EXCEPTION);

        $Reply = $this->_sendNwCtrlRequest(self::BACKUPPLAN_ACTION);
        $this->assertReplyNotSuccessful($Reply, self::SHOULD_FAIL_MSG);
    }

    /**
     * Test BackupPlanStatusCommit action. Should return successful reply if model throws exception.
     */
    public function testBackupPlanStatusCommitActionShouldSucceed()
    {
        $this->_setMockBackupPlan(self::NO_EXCEPTION);
        $this->_setMockCloudStorage(self::NO_EXCEPTION);
        $this->_setMockResource(self::NO_EXCEPTION);

        $Reply = $this->_sendNwCtrlRequest(self::BACKUPPLAN_ACTION);
        $this->assertReplySuccessful($Reply, self::SHOULD_SUCCEED_MSG);
    }

    /**
     * Test backup info commit action. Should return unsuccessful reply if model throws exception.
     */
    public function testBackupInfoCommitActionShouldFail()
    {
        $this->_setMockCloudStorage(self::THROW_EXCEPTION);
        $this->_setMockResource(self::THROW_EXCEPTION);

        $Reply = $this->_sendNwCtrlRequest(self::BACKUPINFO_ACTION);
        $this->assertReplyNotSuccessful($Reply, self::SHOULD_FAIL_MSG);
    }

    /**
     * Test backup info commit action. Should return successful reply.
     */
    public function testBackupInfoCommitActionShouldSucceed()
    {
        $this->_setMockCloudStorage(self::NO_EXCEPTION);
        $this->_setMockResource(self::NO_EXCEPTION);

        $Reply = $this->_sendNwCtrlRequest(self::BACKUPINFO_ACTION);
        $this->assertReplySuccessful($Reply, self::SHOULD_SUCCEED_MSG);
    }

    /**
     * Test redirect to backup cloud. Should fail if model throws exception.
     */
    public function testRedirectToBackupCloudCommitActionShouldFail()
    {
        $this->_setAuthMock(self::THROW_EXCEPTION);

        $Reply = $this->_sendNwCtrlRequest(self::REDIRECT_ACTION);
        $this->assertReplyNotSuccessful($Reply, self::SHOULD_FAIL_MSG);
    }


    /**
     * Test redirect to backup cloud. Should succeed.
     */
    public function testRedirectToBackupCloudCommitActionShouldSucceed()
    {
        $this->_setAuthMock(self::NO_EXCEPTION);

        $Reply = $this->_sendNwCtrlRequest(self::REDIRECT_ACTION);
        $this->assertReplySuccessful($Reply, self::SHOULD_SUCCEED_MSG);
    }


    /**
     * Revoke plan commit action. Should fail if excpetion is thrown in model.
     */
    public function testRevokePlanCommitActionShouldFail()
    {
        $this->_setMockBackupPlan(self::THROW_EXCEPTION);
        $this->_setMockResource(self::THROW_EXCEPTION);


        $Reply = $this->_sendNwCtrlRequest(self::REVOKE_PLAN_ACTION);
        $this->assertReplyNotSuccessful($Reply, self::SHOULD_FAIL_MSG);
    }

    /**
     * Revoke plan commit action. Should succeed.
     */
    public function testRevokePlanCommitActionShouldSucceed()
    {
        $this->_setMockBackupPlan(self::NO_EXCEPTION);
        $this->_setMockResource(self::NO_EXCEPTION);


        $Reply = $this->_sendNwCtrlRequest(self::REVOKE_PLAN_ACTION);
        $this->assertReplySuccessful($Reply, self::SHOULD_SUCCEED_MSG);
    }

    /**
     * Activate plan. Should fail when model throws exception.
     */
    public function testActivatePlanCommitActionShouldFail()
    {
        $this->_setMockBackupPlan(self::THROW_EXCEPTION);
        $this->_setMockCloudStorage(self::THROW_EXCEPTION);
        $this->_setMockResource(self::THROW_EXCEPTION);

        $Reply = $this->_sendNwCtrlRequest(self::ACTIVATE_PLAN_ACTION);
        $this->assertReplyNotSuccessful($Reply, self::SHOULD_FAIL_MSG);
    }

    /**
     * Activate plan. Should succeed.
     */
    public function testActivatePlanCommitActionShouldSucceed()
    {
        $this->_setMockBackupPlan(self::NO_EXCEPTION);
        $this->_setMockResource(self::NO_EXCEPTION);
        $this->_setMockCloudStorage(self::NO_EXCEPTION);


        $Reply = $this->_sendNwCtrlRequest(self::ACTIVATE_PLAN_ACTION);
        $this->assertReplySuccessful($Reply, self::SHOULD_SUCCEED_MSG);
    }

    /**
     * Test run backup action. Should display failure if model throws exception.
     */
    public function testRunBackupCommitActionShouldFail()
    {
        $this->_setMockBackupPlan(self::THROW_EXCEPTION);

        $Reply = $this->_sendNwCtrlRequest(self::RUN_BACKUP_ACTION);
        $this->assertReplyNotSuccessful($Reply, self::SHOULD_FAIL_MSG);
    }

    /**
     * Test run backup action. Should succeed.
     */
    public function testRunBackupCommitActionShouldSucceed()
    {
        $this->_setMockBackupPlan(self::NO_EXCEPTION);
        $this->_setMockResource(self::NO_EXCEPTION);

        $Reply = $this->_sendNwCtrlRequest(self::RUN_BACKUP_ACTION);
        $this->assertReplySuccessful($Reply, self::SHOULD_SUCCEED_MSG);
    }

    /**
     * Test listBackupsCommitAction should return failed request if model throws exception.
     */
    public function testListBackupsCommitActionShouldFail()
    {
        $this->_setMockCloudStorage(self::NO_EXCEPTION);
        $this->_setMockResource(self::THROW_EXCEPTION);

        $Reply = $this->_sendNwCtrlRequest(self::LIST_BACKUPS_ACTION);
        $this->assertReplyNotSuccessful($Reply, self::SHOULD_FAIL_MSG);
    }


    /**
     * Test listBackupCommitAction should return successful reply when model does not throw any exceptions.
     */
    public function testListBackupsCommitActionShouldSucceed()
    {
        $this->_setMockCloudStorage(self::NO_EXCEPTION);
        $this->_setMockResource(self::NO_EXCEPTION);

        $Reply = $this->_sendNwCtrlRequest(self::LIST_BACKUPS_ACTION);
        $this->assertReplySuccessful($Reply, self::SHOULD_SUCCEED_MSG);
    }

    /**
     * make sure ctrl request fails if model throws exception.
     */
    public function testRecoverDirectoriesCommitActionShouldFail()
    {
        $this->_setMockRecoveryPlan(self::THROW_EXCEPTION);
        $Reply = $this->_sendNwCtrlRequest(self::RECOVER_DIRS_ACTION);
        $this->assertReplyNotSuccessful($Reply, self::SHOULD_FAIL_MSG);
    }

    /**
     * Test recoverDirectoriesCommitAction should succeed.
     */
    public function testRecoverDirectoriesCommitActionShouldSucceed()
    {
        $args = array(
            Form_AcronisBackups::INPUT_BACKUP_ID => 'backupId',
            Form_AcronisBackups::INPUT_MULTI_DIR => array('dir')
        );

        $this->_setMockRecoveryPlan(self::NO_EXCEPTION);
        $Reply = $this->_sendNwCtrlRequest(self::RECOVER_DIRS_ACTION, $args);
        $this->assertReplySuccessful($Reply, self::SHOULD_SUCCEED_MSG);
    }

    /**
     * Test restoreToAltLocationCommitAction should succeed.
     */
    public function testRestoreToAltLocationCommitActionShouldFail()
    {
        $args = array(
            Form_AcronisBackups::INPUT_BACKUP_ID => 'backupId',
            Form_AcronisBackups::INPUT_MULTI_DIR => array('dir')
        );

        $this->_setMockRecoveryPlan(self::THROW_EXCEPTION);
        $Reply = $this->_sendNwCtrlRequest(self::RESTORE_ALT_LOCATION_ACTION, $args);
        $this->assertReplyNotSuccessful($Reply, self::SHOULD_FAIL_MSG);
    }

    /**
     * Test restoreToAltLocationCommitAction should succeed.
     */
    public function testRestoreToAltLocationCommitActionShouldSucceed()
    {
        $args = array(
            Form_AcronisBackups::INPUT_BACKUP_ID => 'backupId',
            Form_AcronisBackups::INPUT_MULTI_DIR => array('dir')
        );

        $this->_setMockRecoveryPlan(self::NO_EXCEPTION);
        $Reply = $this->_sendNwCtrlRequest(self::RESTORE_ALT_LOCATION_ACTION, $args);
        $this->assertReplySuccessful($Reply, self::SHOULD_SUCCEED_MSG);
    }
}
