<?php
/**
 * InterWorx Hosting Control Panel
 *
 * <pre>
 * +----------------------------------------------------------------------+
 * | Copyright (c) 2000-2010 InterWorx L.L.C., All Rights Reserved.       |
 * +----------------------------------------------------------------------+
 * | Redistribution and use in source form, with or without modification  |
 * | is NOT permitted without consent from the copyright holder.          |
 * |                                                                      |
 * | THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS "AS IS" AND |
 * | ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,    |
 * | THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A          |
 * | PARTICULAR PURPOSE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,    |
 * | EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,  |
 * | PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR   |
 * | PROFITS; OF BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY  |
 * | OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT         |
 * | (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE    |
 * | USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH     |
 * | DAMAGE.                                                              |
 * +----------------------------------------------------------------------+
 * </pre>
 *
 * @package InterWorx
 * @author  Malin Lorch <mlorch@liquidweb.com>
 * @date    Jun 25, 2020
 */

require_once(__DIR__ . '/AcronisCtrlTest.php');

class Ctrl_Siteworx_AcronisTest extends AcronisCtrlTest
{

    /**
     * index action - should display error message when user not authorized.
     */
    public function testIndexActionShouldFail()
    {
        $isAuthorized = false;
        $this->_setMockOAuthApi($isAuthorized);

        $Reply = $this->_sendSwCtrlRequest(self::INDEX_ACTION);
        $this->assertReplyNotSuccessful($Reply, 'Expected index action to fail when user not authorized');

        $replyData = $Reply->getData();
        $this->assertContains(self::EXPECTED_MESSAGE_NOT_AUTHORIZED, $replyData);
    }

    /**
     * index action
     */
    public function testIndexActionShouldSucceed()
    {
        $Reply = $this->_sendSwCtrlRequest(self::INDEX_ACTION);
        $this->assertReplySuccessful($Reply, 'Expected successful reply');
    }

    /**
     * Test listBackupsCommitAction should return failed request if model throws exception.
     */
    public function testListBackupsCommitActionShouldFail()
    {
        $this->_setMockCloudStorage(self::NO_EXCEPTION);
        $this->_setMockResource(self::THROW_EXCEPTION);

        $Reply = $this->_sendSwCtrlRequest(self::LIST_BACKUPS_ACTION);
        $this->assertReplyNotSuccessful($Reply, self::SHOULD_FAIL_MSG);
    }


    /**
     * Test listBackupCommitAction should return successful reply when model does not throw any exceptions.
     */
    public function testListBackupsCommitActionShouldSucceed()
    {
        $this->_setMockCloudStorage(self::NO_EXCEPTION);
        $this->_setMockResource(self::NO_EXCEPTION);

        $Reply = $this->_sendSwCtrlRequest(self::LIST_BACKUPS_ACTION);
        $this->assertReplySuccessful($Reply, self::SHOULD_SUCCEED_MSG);
    }

    /**
     * make sure ctrl request fails if model throws exception.
     */
    public function testRecoverDirectoriesCommitActionShouldFail()
    {
        $this->_setMockRecoveryPlan(self::THROW_EXCEPTION);
        $Reply = $this->_sendSwCtrlRequest(self::RECOVER_DIRS_ACTION);
        $this->assertReplyNotSuccessful($Reply, self::SHOULD_FAIL_MSG);
    }

    /**
     * Test recoverDirectoriesCommitAction should succeed.
     */
    public function testRecoverDirectoriesCommitActionShouldSucceed()
    {
        $args = array(
            Form_AcronisBackups::INPUT_BACKUP_ID => 'backupId',
            Form_AcronisBackups::INPUT_MULTI_DIR => array('dir')
        );

        $this->_setMockRecoveryPlan(self::NO_EXCEPTION);
        $Reply = $this->_sendSwCtrlRequest(self::RECOVER_DIRS_ACTION, $args);
        $this->assertReplySuccessful($Reply, self::SHOULD_SUCCEED_MSG);
    }


    /**
     * Test restoreToAltLocationCommitAction should succeed.
     */
    public function testRestoreToAltLocationCommitActionShouldFail()
    {
        $args = array(
            Form_AcronisBackups::INPUT_BACKUP_ID => 'backupId',
            Form_AcronisBackups::INPUT_MULTI_DIR => array('dir')
        );

        $this->_setMockRecoveryPlan(self::THROW_EXCEPTION);
        $Reply = $this->_sendSwCtrlRequest(self::RESTORE_ALT_LOCATION_ACTION, $args);
        $this->assertReplyNotSuccessful($Reply, self::SHOULD_FAIL_MSG);
    }

    /**
     * Test restoreToAltLocationCommitAction should succeed.
     */
    public function testRestoreToAltLocationCommitActionShouldSucceed()
    {
        $args = array(
            Form_AcronisBackups::INPUT_BACKUP_ID => 'backupId',
            Form_AcronisBackups::INPUT_MULTI_DIR => array('dir')
        );

        $this->_setMockRecoveryPlan(self::NO_EXCEPTION);
        $Reply = $this->_sendSwCtrlRequest(self::RESTORE_ALT_LOCATION_ACTION, $args);
        $this->assertReplySuccessful($Reply, self::SHOULD_SUCCEED_MSG);
    }
}
