
import {
    createSpinner,
    toggleVisibility
} from '../helpers.js';

const $warningMessageContainer = $('#ab-restore-warning-message');
const $successMessageDiv = $('#ab-restore-success-message');
const $successMessageContainer = $successMessageDiv.parent();

export const $table = $('#ab-backups-table');
export const $tableHeader = $('#ab-table-header');

export const createTableRow = (id, className, $content, displayPath) => (
    `<tr class="${className}" id="${id}" data-path="${displayPath}">
        ${displayContent($content)}
    </tr>
    `);


const displayContent = $content => Array.isArray($content) ? getTableItems($content) : getTableItem($content);
const getTableItems = $items => $items.map($item => getTableItem($item));
const getTableItem = $item => `<td>${$item}</td>`;

export const createHeaderRow = $content => $content.map($headerContent => `<th>${$headerContent}</th>`);

export const displaySpinner = () => {
    let $spinner = createSpinner();
    $table.html(`<div>${$spinner} ${loadingBackupMessage}</div>`);
}

export const emptyTable = () => $table.html('');

const loadingBackupMessage = 'Loading the content. This may take a while.';

export const formatDate = date => `${date.day} ${date.month} ${date.year} ${date.time}`;

export const getLinkDisplayName = ($tableElement) => {
    let $link = $tableElement.find('a');
    return $link.text();
}

export const getTableElementId = ($element) => {
    while (!$element.is('tr')) {
        $element = $element.parent();
    }

    return $element.attr('id');
}

export const replaceTableContent = ($headerContent, $tableContent) => {
    $tableHeader.html($headerContent);
    $table.html($tableContent);
}

export const getSelectedDirs = () => $table.find('input[type=checkbox]:checked');

export const getAllCheckboxes = () => $('input[type=checkbox]');

export const hideInProgress = () => {
    if ($warningMessageContainer.is(':visible')) {
        toggleVisibility($warningMessageContainer);
    }
}

export const showInProgress = ($message) => {
    if ($warningMessageContainer.is(':hidden')) {
        $warningMessageContainer.html($message);
        toggleVisibility($warningMessageContainer);
    }
}

export const showSuccess = ($message) => {
    if ($successMessageContainer.is(':hidden')) {
        closeSuccessMessageOnClick();
        $successMessageDiv.html($message);
        toggleVisibility($successMessageContainer);
    } else {
        $successMessageDiv.html($message);
    }
}

const closeSuccessMessageOnClick = () => {
    let $closeButton = $('#ab-close-success');
    // make sure multiple event handlers aren't registered
    $closeButton.unbind('click');
    $closeButton.on('click', () => toggleVisibility($successMessageContainer))

}

export const getSelectedDirIds = () => {
    let $directories = getSelectedDirs();
    let $dirIds = $directories.map(($index, $dir) => $($dir.closest('tr')).attr('id'));
    return $dirIds.get();
}




export const dirsSelected = () => getSelectedDirs().length > 0;

export const getTextSelectedDirNames = () => {
    let $selected = getSelectedDirs();
    let names = '';

    $selected.each((index, dir) => {
        let $checkbox = $(dir);
        let $tableElement = $checkbox.parent().parent();

        let $nameElement = $tableElement.find('span').parent();
        let name = $nameElement.text().trim();
        names.length > 0 ? names += `, ${name}` : names = name;
    });

    return names;
}

export const closeModal = () => iw_lib.iw_modal_popup.hide();



