import {
    setBreadcrumbs,
    getBreadcrumbs,
    setBackupId
} from '../sessionStorage/sessionStorage.js';
import { updateNavigation } from './navigation.js';

const dirClass = 'ab-breadcrumbs-dir';
const backupClass = 'ab-breadcrumbs-backup';
const $breadcrumbsDiv = $(`#ab-breadcrumbs`);


export const createBreadcrumbs = (backupId, displayName) => {
    setBackupId(backupId);
    updateNavigation(displayName, backupId);
}


export const addToBreadcrumbs = (name, id) => {
    let newPath = `${getBreadcrumbs()}/${name.trim()}`;
    updateNavigation(newPath, id);
}

export const registerBreadcrumbsEventHandler = () => {
    $('body').off('click', `.${dirClass}`);
    $('body').on('click', `.${dirClass}`, (event) => {
        let $targetElement = $(event.currentTarget);
        let $breadcrumbsElements = $targetElement.parent().children();
        let currentIndex = $breadcrumbsElements.index($targetElement);

        let currentBreadcrumbs = getBreadcrumbs().split('/').slice(0, currentIndex);
        let updatedBreadcrumbs = currentBreadcrumbs.join('/');

        updateNavigation(updatedBreadcrumbs);
    });
}

export const removeBreadcrumbs = () => $breadcrumbsDiv.html('');

export const displayBreadcrumbs = (path) => {
    setBreadcrumbs(path);

    let $breadcrumbs = getBackupsLink();
    let items = path.split('/');

    items.forEach((name, index) => {
        let isLast = index === items.length - 1;
        $breadcrumbs += isLast ? ` > ${name}` : ` > ${getDirLink(name)}`;
    });

    $breadcrumbsDiv.html($breadcrumbs);
}


const getBackupsLink = () => {
    let pathname = window.location.pathname.substr(1).split('/')[0];
    let url = `/${pathname}/acronis?tab=backups`;
    return `<a href="${url}">Backups</a>`;
}

const getDirLink = (name) => `<a class="${dirClass}"> ${name}</a>`;