import {
    toggleVisibility,
    handleResponseError
} from '../helpers.js';

import {
    emptyTable,
    replaceTableContent,
    createTableRow,
    formatDate,
    $table,
    getLinkDisplayName,
    displaySpinner
} from './backupsHelpers.js';

import { createBreadcrumbs, registerBreadcrumbsEventHandler } from './breadcrumbs.js';
import { removeHashOnLoad } from './../backups/navigation.js';


const tableEmptyId = 'ab-no-backups';
export const backupItemClass = 'ab-backup-item';

export const registerBackupsEventHandler = (functionToCall) => {
    $table.unbind();
    $table.on('click', `.${backupItemClass}`, (event) => {
        let $targetElement = $(event.currentTarget);
        let displayName = getLinkDisplayName($targetElement)
        let backupId = $targetElement.attr('id');

        displaySpinner();
        createBreadcrumbs(backupId, displayName);
        functionToCall(backupId)
    });

    removeHashOnLoad();
}

export const listBackupsCallback = (reply, success) => {
    if (!success) {
        handleResponseError(reply);
    } else {
        registerBreadcrumbsEventHandler();
        listBackups(reply);
    }
}

const listBackups = (reply) => {
    let backups = reply.getReplyData();

    if (backups.length === 0) {
        emptyTable();
        toggleVisibility(tableEmptyId);
    } else {
        let $tableRows = getTableRows(backups);
        let $tableHeader = `<th>Date & time</th>`;
        replaceTableContent($tableHeader, $tableRows);
    }
}

const getTableRows = (backups) => backups.map(backup => {
    let $rowContent = getDateLink(backup.date);
    let $tableRow = createTableRow(backup.backupId, backupItemClass, $rowContent);

    return $tableRow;
});

const getDateLink = (date) => `<a>${formatDate(date)}</a>`;
