import { handleResponseError } from '../helpers.js';
import { addToBreadcrumbs } from './breadcrumbs.js';
import { displayRecoveryButtons } from './recoveryButtons.js';
import {
    createTableRow,
    createHeaderRow,
    replaceTableContent,
    formatDate,
    $table,
    $tableHeader,
    getLinkDisplayName
} from './backupsHelpers.js';

const dirClass = 'ab_directory';
const loadDirClass = 'ab_load_directory';
const fileClass = 'ab_file';
const checkboxClass = 'ab-recovery-checkbox';
const $checkboxHtml = `<input type="checkbox" class="${checkboxClass}">`;


export const displayDirContent = (reply, success) => {
    if (!success) {
        handleResponseError(reply);
    } else {
        displayRecoveryButtons();

        let dirContent = reply.getReplyData();
        let $newTableContent = getNewTableContent(dirContent);
        let $newTableHeader = createHeaderRow([$checkboxHtml, 'Name', 'Modified']);

        replaceTableContent($newTableHeader, $newTableContent);
        updateNavigationOnTableClick();
        addSelectAllListener();
    }
}

const getNewTableContent = (content) => {
    // sorting content so that dirs are displayed before files
    let sortedContent = content.sort((a, b) => (a.type > b.type) ? 1 : ((b.type > a.type) ? -1 : 0));
    let rows = getRows(sortedContent);
    return rows;
};

const getRows = (content) => content.map(dir => {
    let className = isFile(dir) ? fileClass : dirClass;
    let $displayContent = getDisplayContent(dir);

    return createTableRow(dir.id, className, $displayContent, dir.displayPath);
});

const getDisplayContent = (dir) => {
    let $nameElement = isFile(dir) ? getFileNameElement(dir.name) : getDirectoryNameElement(dir.name);
    let $size = isFile(dir) ? dir.size : '';
    let $modified = formatDate(dir.modified);

    return [$checkboxHtml, $nameElement, $modified, $size];
}

const getFileNameElement = (fileName) => (
    `
    <div>
        <span class="ab-icon ab-icon-file"></span>
        ${fileName}
    </div>
    `
);

const getDirectoryNameElement = (dirName) => (
    `
    <div class="${loadDirClass}">
        <span class="ab-icon ab-icon-folder"></span>
        <a>
            ${dirName}
        </a>
    </div>
    `
);

const isFile = (dir) => dir.type === 'file';

const addSelectAllListener = () => {
    let $tableHeaderCheck = $tableHeader.find(`.${checkboxClass}`);
    $tableHeaderCheck.unbind('click');
    $tableHeaderCheck.on('click', toggleSelectAll);
}

const toggleSelectAll = (event) => {
    let checkAllOrNone = $(event.target).prop('checked');
    $(`.${checkboxClass}`).prop('checked', checkAllOrNone);
}



const updateNavigationOnTableClick = () => {
    $table.off('click', `.${loadDirClass}`);
    $table.on('click', `.${loadDirClass}`, (event) => {
        let $targetElement = $(event.currentTarget).closest('tr');
        let id = $targetElement.attr('id');
        let name = getLinkDisplayName($targetElement);

        addToBreadcrumbs(name, id)
    });
}
