import {
    hideInProgress,
    showSuccess,
    getTextSelectedDirNames
} from './backupsHelpers.js';

import { getRecoveryNames } from '../sessionStorage/sessionStorage.js';
import { handleResponseError } from '../helpers.js';

const checkboxDeleteId = 'acronis-delete-checkbox';
const recoverBtnId = 'recovery-button';

const $openModalButton = $('#ab-open-recovery-modal');

export const openRecoveryModalOnClick = () => {
    //make sure multiple event handlers aren't added.
    $openModalButton.unbind('click');
    $openModalButton.on('click', openModal);
}

const openModal = () => {
    let header = 'Recover Files';
    let $content = getRecoveryContent();
    iw_lib.popupModal($content, header);
}

const getRecoveryContent = () => {
    let filesToBeRecovered = getTextSelectedDirNames();

    let message = `The following files will be recovered: ${filesToBeRecovered}`;
    let $warningMessage = getWarningHtml();
    let $recoveryButton = getRecoveryButtonHtml();
    let $deleteCheckbox = getDeleteCheckboxHtml();

    return (
        `<div class="ab-modal-content">${$warningMessage}
        ${message}

        ${$deleteCheckbox}
        ${$recoveryButton}</div>`);
}

const getWarningHtml = () => {
    let warningMessage = 'Note that the operating system of the InterWorx host may work incorrectly if you recover system files.';
    return `<div class="ab-alert ab-alert-warning">${warningMessage}</div>`;
}

const getRecoveryButtonHtml = () => `<button id="${recoverBtnId}" class="ab-buttons">Start recovery</button>`;
const getDeleteCheckboxHtml = () => `<span><input type="checkbox" id="${checkboxDeleteId}"> ${getLabel()}</span>`;
const getLabel = () => `<label for="${checkboxDeleteId}">${getLabelText()}</label>`;
const getLabelText = () => 'Delete any files in the original location that were created after the backup';

export const deleteCheckboxSelected = () => $(`#${checkboxDeleteId}`).prop('checked');

export const registerEventListenerRecoveryButton = (functionToCall) => {
    let recoveryButton = `#${recoverBtnId}`;
    $('body').off('click', recoveryButton, functionToCall);
    $('body').on('click', recoveryButton, functionToCall);
}


export const callbackRecoverFiles = (reply, success) => {
    hideInProgress();

    if (!success) {
        handleResponseError(reply);
    } else {
        let successMessage = 'Successfully recovered files: ' + getRecoveryNames();
        showSuccess(successMessage);
    }
}
