import { getSelectedDirIds } from './backups/backupsHelpers.js';
import { getBackupId } from './sessionStorage/sessionStorage.js';

const nwCtrl = '/nodeworx/acronis';
const swCtrl = '/siteworx/acronis';

const xhrTokenInput = {
    iw_payload_output: 'json',
    security_token: iw_js_data.iw_env.security_token
};

const xhrTokenInputArgs = (backupId, dirId) => ({
    ab_backup_id: backupId,
    ab_directory_id: dirId
});

const xhrInputWithSelectedDirs = () => {
    let dirIds = getSelectedDirIds();

    let input = xhrTokenInputArgs(getBackupId());
    input['ab_directories_ids'] = dirIds;

    return input;
}

export const sendNwCtrlRequest = (actionToCall, callback, args) => {
    sendCtrlRequest(nwCtrl, callback, actionToCall, args);
};

export const sendSwCtrlRequest = (actionToCall, callback, args) => {
    sendCtrlRequest(swCtrl, callback, actionToCall, args);
};

const sendCtrlRequest = (ctrl, callback, action, args) => {
    iw_ctrl_handler.execute(null, callback, ctrl, action, {...xhrTokenInput, ...args})
}



export const getDirXhr = (backupId, dirId) => ({
    action: 'getDirectoryContentCommit',
    input: xhrTokenInputArgs(backupId, dirId)
});

export const getRootXhr = (backupId) => ({
    action: 'getRootContentCommit',
    input: xhrTokenInputArgs(backupId)
});

export const recoverXhr = (deleteOldFiles) => {
    let input = xhrInputWithSelectedDirs();
    input['ab_delete_files'] = deleteOldFiles;

    return {
        action: 'recoverDirectoriesCommit',
        input: input
    };
}

export const restoreAltLocationXhr = () => ({
    action: 'restoreToAltLocationCommit',
    input: xhrInputWithSelectedDirs()
});

export const listBackupsXhr = () => ({
    action: 'listBackupsCommit'
});

export const getAltLocationXhr = () => ({
    action: 'getRestoreAltLocation'
});