import {
    closeModal,
    showInProgress,
    getTextSelectedDirNames,
    dirsSelected,
    displaySpinner
} from '../../backups/backupsHelpers.js';

import { getDirXhr, getRootXhr, recoverXhr, restoreAltLocationXhr, sendNwCtrlRequest } from './../../ctrlActions.js';
import { registerEventListenerRecoveryButton, deleteCheckboxSelected, callbackRecoverFiles } from '../../backups/recoveryModal.js';
import { registerEventListenerAltLocationButton, callbackRestoreAltLocation } from './../../backups/altLocationModal.js';
import { displayDirContent } from '../../backups/listDirContent.js';
import { getBackupId, setRecoveryNames } from './../../sessionStorage/sessionStorage.js';

export const loadRecoveryPoint = (backupId) => {
    displaySpinner();

    let xhrData = getRootXhr(backupId);
    sendNwCtrlRequest(xhrData.action, callbackLoadContent, xhrData.input);
}

const callbackLoadContent = (reply, success) => {
    displayDirContent(reply, success);

    registerEventListenerRecoveryButton(recoverDirectoriesOnClick)
    registerEventListenerAltLocationButton(restoreToAltLocation);
}

export const loadDirectory = (dirId) => {
    displaySpinner();

    let backupId = getBackupId();
    let xhr = getDirXhr(backupId, dirId);

    sendNwCtrlRequest(xhr.action, callbackLoadContent, xhr.input);
}

const recoverDirectoriesOnClick = (event) => {
    // get this value before modal is closed
    let deleteOldFiles = deleteCheckboxSelected();
    closeModal();
    if (dirsSelected()) {
        let filesToRecover = getTextSelectedDirNames();
        setRecoveryNames(filesToRecover);

        let xhrData = recoverXhr(deleteOldFiles);
        sendNwCtrlRequest(xhrData.action, callbackRecoverFiles, xhrData.input);
        showInProgress('Recovery in progress...');
    }

}


const restoreToAltLocation = () => {
    closeModal();

    if (dirsSelected()) {
        showInProgress('Downloading files to server...');
        let xhrData = restoreAltLocationXhr();
        sendNwCtrlRequest(xhrData.action, callbackRestoreAltLocation, xhrData.input);
    }
}

