import { sendNwCtrlRequest } from '../../ctrlActions.js';

import {
    abCreateTitleCol,
    abCreateCol,
    abCreateRow
} from './dashboardHelpers.js';

import {
    createSpinner,
    setMessageAndRefreshPage,
    handleResponseError
} from '../../helpers.js';

const toggleId = 'ab-backup-enabled';

/**
 * Export section.
 * action: the action to call in the controller.
 */
export let abBackupSection = {
    action: 'backupPlanStatusCommit',
    callback: (reply, success) => {

        if (!success) {
            handleResponseError(reply);
        } else {
            loadBackupContent(reply);
        }
    }
}

const loadBackupContent = (reply) => {
    let backupData = reply.getReplyData();
    let enabled = backupData ? backupData.enabled : false;

    let $firstRow = createBackupFirstRow(enabled);
    let $thirdRow = createBackupThirdRow();
    let content = [$firstRow, $thirdRow];

    if (enabled) {
        let $secondRow = createBackupSecondRow(backupData.type, backupData.time);
        // add second row to content.
        content.splice(1, 0, $secondRow);
    }

    let $container = getContainer();
    $container.html(content);
}

let getContainer = () => $('#dashboard-backup');

let createBackupFirstRow = (enabled) => {
    let $titleCol = abCreateTitleCol('BACKUP');

    let $toggleContent = createToggleContent(enabled);
    let $toggleCol = abCreateCol($toggleContent);
    $toggleCol.addClass('text-right ab-toggle-col');

    let $firstRow = abCreateRow([$titleCol, $toggleCol]);
    return $firstRow;
}

let createToggleContent = (enabled) => {
    let toggleTextContent = enabled ? 'On' : 'Off';

    let $toggleSpan = createToggleTextElement(toggleTextContent);
    let $toggleDiv = createToggle(enabled);

    let $div = $('<div></div>');
    $div.append([$toggleSpan, $toggleDiv]);

    return $div;
}

let createBackupSecondRow = (type, time) => {
    let backupText = getBackupText(type, time);
    let backupTextCol = abCreateCol(backupText);

    let secondRowChildren = [backupTextCol];
    let secondRow = abCreateRow(secondRowChildren);

    return secondRow;
}

let createBackupThirdRow = () => {
    let backupConsoleLink = getBackupConsoleLink();
    let backupConsoleCol = abCreateCol(backupConsoleLink);
    let thirdRow = abCreateRow([backupConsoleCol]);
    return thirdRow;
}

let createToggleTextElement = (textContent) => {
    let $span = $(`<span id="${toggleId}">${textContent}</span>`);
    return $span;
}

let createToggleShuttle = (enabled) => {
    let toggleStatusClass = enabled ? 'ab-on' : 'ab-off';
    let $toggle = $(`<span id="${toggleId}" class="${toggleStatusClass} ab-shuttle"></span>`);
    return $toggle;
}

let createToggle = (enabled) => {
    let $toggleDiv = $(`<div class="ab-switcher" id="backup-switcher"></div>`);
    let $toggle = createToggleShuttle(enabled);

    $toggleDiv.append($toggle);
    $toggleDiv.on('click', () => toggleAction(enabled));
    return $toggleDiv;
}

let toggleAction = (enabled) => {
    let $spinner = createSpinner();
    replaceToggleContent($spinner);

    let action = enabled ? 'revokePlanCommit' : 'activatePlanCommit';
    sendNwCtrlRequest(action, toggleCallback);
}

let toggleCallback = (reply, success) => {
    if (!success) {
        handleResponseError(reply);
    } else {
        let replyData = reply.getReplyData();
        let action = replyData.enabled ? 'enabled' : 'disabled';
        let message = `Backup has been ${action}.`

        setMessageAndRefreshPage('success', message);
    }
}

let getToggleCol = () => {
    let $container = getContainer();
    return $container.find('.ab-toggle-col');
}

let replaceToggleContent = ($newElement) => {
    let $toggleCol = getToggleCol();
    $toggleCol.html($newElement);
}

let getBackupText = (type, time) => {
    let displayHour = formatHour(time.hour);
    let displayMinutes = formatMinute(time.minute);
    let period = formatTimePeriod(time.hour);

    let displayText = type === 'daily' ? 'Everyday at ' : 'Monday to Friday at ';
    let displayTime = `${displayHour}:${displayMinutes} ${period}`;

    return $(`<p>${displayText} ${displayTime}</p>`);
}

let formatHour = (hour) => hour > 12 ? (hour - 12) : hour;
let formatMinute = (minute) => minute < 10 ? `0${minute}` : minute;
let formatTimePeriod = (hour) => hour < 12 ? 'AM' : 'PM';

let getBackupConsoleLink = () => {
    let $a = $('<a>Go to backup console</a>');
    $a.on('click', cloudLinkAction);
    return $a;
}

let cloudLinkAction = () => {
    let action = 'redirectToBackupCloudCommit';
    sendNwCtrlRequest(action, callbackRedirectToBackupCloud);
}

let callbackRedirectToBackupCloud = (reply, success) => {
    if (!success) {
        handleResponseError(reply);
    } else {
        // opening in new tab is blocked in firefox.
        let replyData = reply.getReplyData();
        let redirectUrl = replyData.redirect.replace('&amp;', '&');
        window.location = redirectUrl;
    }
}
