import { sendNwCtrlRequest } from '../../ctrlActions.js';

import {
    abCreateTitleCol,
    abCreateCol,
    abCreateRow,
    getBackupDateColNoDate,
    getBackupTimeCol,
    getBackupDateCol
} from './dashboardHelpers.js';


import {
    createSpinner,
    setMessageAndRefreshPage,
    handleResponseError
} from '../../helpers.js';

const runBackupContainerId = 'ab-run-backup';

export let abNextBackupSection = {
    // action to call in ctrl.
    action: 'backupInfoCommit',
    callback: (reply, success) => {
        if (!success) {
            handleResponseError(reply);
        } else {
            loadNextBackupContent(reply);
        }
    }
}

const loadNextBackupContent = (reply) => {
    let replyData = reply.getReplyData();
    let nextBackupDate = replyData.nextBackup;

    let $firstRow = getFirstRow(nextBackupDate);
    let $secondRow = nextBackupDate ? getSecondRow(nextBackupDate.time) : getSecondRowNoData();

    let $container = $('#dashboard-nextbackup');
    $container.html([$firstRow, $secondRow]);
}

let getFirstRow = (date) => {
    let $titleCol = abCreateTitleCol('NEXT BACKUP');
    let $backupDateCol = date ? getBackupDateCol(date) : getBackupDateColNoDate('Not scheduled');

    // add cols to row
    let rowContent = [$titleCol, $backupDateCol];
    let $firstRow = abCreateRow(rowContent);
    return $firstRow;
}

let getSecondRow = (time) => {
    let $backupLinkCol = getBackupLinkCol();
    let $backupTimeCol = getBackupTimeCol(time);
    let rowContent = [$backupLinkCol, $backupTimeCol];

    let $row = abCreateRow(rowContent);
    $row.addClass('vertical-spacer');

    return $row;
}

let getSecondRowNoData = () => {
    let $backupTimeCol = getBackupTimeCol();
    let rowContent = [$backupTimeCol];

    let $row = abCreateRow(rowContent);
    $row.addClass('vertical-spacer');

    return $row;
}

let getBackupLinkCol = () => {

    let $img = $('<img class="backup-icon" src="/plugins/assets/acronis/images/ico_run_now.svg" alt="backup now">');
    let $span = $(`<span>Run now</span>`);

    let $link = $(`<a></a>`);
    $link.on('click', runBackup);
    $link.append([$img, $span]);

    let $div = $(`<div id="${runBackupContainerId}"></div>`);
    $div.append($link);

    let $col = abCreateCol($div);
    return $col;
}

let getRunBackupContainer = () => $(`#${runBackupContainerId}`);

let runBackup = () => {

    addSpinnerToBackupAction();
    let action = 'runBackupCommit';
    sendNwCtrlRequest(action, runBackupCallback);
}

let addSpinnerToBackupAction = () => {
    let $runBackupContainer = getRunBackupContainer();
    let $spinner = createSpinner();

    $runBackupContainer.html($spinner);
}

let runBackupCallback = (reply, success) => {
    if (!success) {
        handleResponseError(reply);
    } else {
        let type = 'success';
        let message = 'The backup has started.';
        setMessageAndRefreshPage(type, message);
    }
}