import { displaySpinner, closeModal, dirsSelected, getTextSelectedDirNames, showInProgress } from '../../backups/backupsHelpers.js';
import { getDirXhr, recoverXhr, sendSwCtrlRequest, restoreAltLocationXhr, getRootXhr } from '../../ctrlActions.js';
import { displayDirContent } from '../../backups/listDirContent.js';
import { registerEventListenerRecoveryButton, deleteCheckboxSelected, callbackRecoverFiles } from '../../backups/recoveryModal.js';
import { registerEventListenerAltLocationButton, callbackRestoreAltLocation } from '../../backups/altLocationModal.js';
import { setRecoveryNames, getBackupId } from '../../sessionStorage/sessionStorage.js';

export const loadRecoveryPoint = (backupId) => {
     displaySpinner();

     let xhrData = getRootXhr(backupId);
     sendSwCtrlRequest(xhrData.action, callbackLoadContent, xhrData.input);
}


const callbackLoadContent = (reply, success) => {
    displayDirContent(reply, success);

    registerEventListenerRecoveryButton(recoverDirectoriesOnClick)
    registerEventListenerAltLocationButton(restoreToAltLocation);
}

const recoverDirectoriesOnClick = (event) => {
    // get this value before modal is closed
    let deleteOldFiles = deleteCheckboxSelected();
    closeModal();

    if (dirsSelected()) {
        let filesToRecover = getTextSelectedDirNames();
        setRecoveryNames(filesToRecover);

        let xhrData = recoverXhr(deleteOldFiles);
        sendSwCtrlRequest(xhrData.action, callbackRecoverFiles, xhrData.input);
        showInProgress('Recovery in progress...');
    }

}


export const loadDirectory = (dirId) => {
    displaySpinner();

    let backupId = getBackupId();
    let xhrData = getDirXhr(backupId, dirId);

    sendSwCtrlRequest(xhrData.action, callbackLoadContent, xhrData.input);
}


const restoreToAltLocation = () => {
    closeModal();

    if (dirsSelected()) {
        showInProgress('Downloading files to server...');
        let xhrData = restoreAltLocationXhr();
        sendSwCtrlRequest(xhrData.action, callbackRestoreAltLocation, xhrData.input);
    }
}

